@@ -47,10 +47,6 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  * DGA
  */
 
-#ifndef USE_DDC2
-#define USE_DDC2 0
-#endif
-
 /*
  * These are X and server generic header files.
  */
@@ -191,70 +187,6 @@ static const OptionInfoRec I740Options[] = {
   { -1, NULL, OPTV_NONE, {0}, FALSE}
 };
 
-static const char *vgahwSymbols[] = {
-    "vgaHWGetHWRec",
-    "vgaHWSave", /* Added */
-    "vgaHWRestore", /* Added */
-    "vgaHWProtect",
-    "vgaHWInit",
-    "vgaHWMapMem",
-    "vgaHWSetMmioFuncs",
-    "vgaHWGetIOBase",
-    "vgaHWLock",
-    "vgaHWUnlock",
-    "vgaHWFreeHWRec",
-    "vgaHWSaveScreen",
-    "vgaHWHandleColormaps",
-    0
-};
-
-#ifdef XFree86LOADER
-static const char *fbSymbols[] = {
-    "fbScreenInit",
-    "fbPictureInit",
-    NULL
-};
-#endif
-
-static const char *xaaSymbols[] = {
-    "XAADestroyInfoRec",
-    "XAACreateInfoRec",
-    "XAAInit",
-    NULL
-};
-
-static const char *ramdacSymbols[] = {
-    "xf86InitCursor",
-    "xf86CreateCursorInfoRec",
-    "xf86DestroyCursorInfoRec",
-    NULL
-};
-
-#ifdef XFree86LOADER
-static const char *vbeSymbols[] = {
-    "VBEInit",
-    "vbeDoEDID",
-    "vbeFree",
-    NULL
-};
-#endif
-
-#if USE_DDC2
-static const char *ddcSymbols[] = {
-  "xf86PrintEDID",
-  "xf86DoEDID_DDC1",
-  "xf86DoEDID_DDC2",
-    NULL
-};
-
-static const char *i2cSymbols[] = {
-  "xf86CreateI2CBusRec",
-  "xf86I2CBusInit",
-    NULL
-};
-#endif
-
-
 #ifdef XFree86LOADER
 
 static MODULESETUPPROTO(i740Setup);
@@ -291,17 +223,6 @@ i740Setup(pointer module, pointer opts, int *errmaj, int *errmin)
 	 * by calling LoadSubModule().
 	 */
 
-	/*
-	 * Tell the loader about symbols from other modules that this module
-	 * might refer to.
-	 */
-	LoaderRefSymLists(vgahwSymbols, fbSymbols, xaaSymbols, 
-			  ramdacSymbols, vbeSymbols,
-#if USE_DDC2
-			  ddcSymbols, i2cSymbols,
-#endif
-			  NULL);
-
 	/*
 	 * The return value must be non-NULL on success even though there
 	 * is no TearDownProc.
@@ -454,6 +375,7 @@ I740Probe(DriverPtr drv, int flags) {
   return foundScreen;
 }
 
+/* Ugh.  Can we not do this? */
 static void
 I740ProbeDDC(ScrnInfoPtr pScrn, int index)
 {
@@ -503,8 +425,6 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
   /* The vgahw module should be loaded here when needed */
   if (!xf86LoadSubModule(pScrn, "vgahw")) return FALSE;
 
-  xf86LoaderReqSymLists(vgahwSymbols, NULL);
-
   /* Allocate a vgaHWRec */
   if (!vgaHWGetHWRec(pScrn)) return FALSE;
 
@@ -745,6 +665,32 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
   clockRanges->interlaceAllowed = FALSE; /*PL*/
   clockRanges->doubleScanAllowed = TRUE; /*PL*/
 
+  { /*PL*/
+
+   if (xf86LoadSubModule(pScrn, "ddc")) {
+     if (xf86LoadSubModule(pScrn, "i2c") ) {
+       if (I740MapMem(pScrn)) {
+	   if (I740_I2CInit(pScrn))
+	     {
+	       xf86MonPtr MonInfo;
+	       if ((MonInfo = xf86DoEDID_DDC2(pScrn->scrnIndex,pI740->rc_i2c))) {
+		 xf86DrvMsg(pScrn->scrnIndex, X_INFO, "DDC Monitor info: %p\n",
+			    MonInfo);
+		 xf86PrintEDID( MonInfo );
+		 xf86DrvMsg(pScrn->scrnIndex, X_INFO, "end of DDC Monitor "
+			    "info\n\n");
+		 xf86SetDDCproperties(pScrn,MonInfo);
+	       }
+	     }
+	   else
+	     xf86DrvMsg(pScrn->scrnIndex,X_ERROR,"I2C initialization failed\n");
+	   
+	   I740UnmapMem(pScrn);
+	 }
+     }
+   }
+  }
+
   i = xf86ValidateModes(pScrn, pScrn->monitor->Modes,
 			pScrn->display->modes, clockRanges,
 			0, 320, 1600,
@@ -777,14 +723,12 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
     I740FreeRec(pScrn);
     return FALSE;
   }
-  xf86LoaderReqSymbols("fbScreenInit","fbPictureInit", NULL);
 
   if (!xf86ReturnOptValBool(pI740->Options, OPTION_NOACCEL, FALSE)) {
     if (!xf86LoadSubModule(pScrn, "xaa")) {
       I740FreeRec(pScrn);
       return FALSE;
     }
-    xf86LoaderReqSymLists(xaaSymbols, NULL);
   }
 
   if (!xf86ReturnOptValBool(pI740->Options, OPTION_SW_CURSOR, FALSE)) {
@@ -792,7 +736,6 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
       I740FreeRec(pScrn);
       return FALSE;
     }
-    xf86LoaderReqSymLists(ramdacSymbols, NULL);
   }
 
   /*  We wont be using the VGA access after the probe */
@@ -819,40 +762,6 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
     pI740->usevgacompat=FALSE;
 
 
-#if USE_DDC2 /*DDC2*/
-  { /*PL*/
-
-   if (xf86LoadSubModule(pScrn, "ddc")) {
-     xf86LoaderReqSymLists(ddcSymbols, NULL);
-     if ( xf86LoadSubModule(pScrn, "i2c") ) {
-       xf86LoaderReqSymLists(i2cSymbols,NULL);
-
-       if (I740MapMem(pScrn))
-	 {
-	   if (I740_I2CInit(pScrn))
-	     {
-	       xf86MonPtr MonInfo;
-
-	       if ((MonInfo = xf86DoEDID_DDC2(pScrn->scrnIndex,pI740->rc_i2c))) {
-		 xf86DrvMsg(pScrn->scrnIndex, X_INFO, "DDC Monitor info: %p\n",
-			    MonInfo);
-		 xf86PrintEDID( MonInfo );
-		 xf86DrvMsg(pScrn->scrnIndex, X_INFO, "end of DDC Monitor "
-			    "info\n\n");
-		 xf86SetDDCproperties(pScrn,MonInfo);
-	       }
-
-	       //xf86SetDDCproperties(pScrn,xf86PrintEDID(  xf86DoEDID_DDC2(pScrn->scrnIndex,pI740->rc_i2c)));
-	     }
-	   else
-	     xf86DrvMsg(pScrn->scrnIndex,X_ERROR,"I2C initialization failed\n");
-	   
-	   I740UnmapMem(pScrn);
-	 }
-     }
-   }
-  }
-#endif /*DDC2*/
 
   { /* Overlay */
     pI740->colorKey = (1 << pScrn->offset.red) | (1 << pScrn->offset.green) |
